@@ -1,5 +1,5 @@
-#ifndef CLEANDIALOG_H
-#define CLEANDIALOG_H
+#ifndef Header_Clean_Dialog
+#define Header_Clean_Dialog
 
 #include "latexdocument.h"
 #include "mostQtHeaders.h"
