@@ -38,6 +38,8 @@ public:
 	void setContextWords(const QSet<QString> &newwords, const QString &context);
 	void setKeyValWords(const QString &name, const QSet<QString> &newwords);
 
+    void setEnvironmentFilter(const QString &filter);
+
     void setDisableMostUsedSorting(bool set);
 
 private:
@@ -64,6 +66,8 @@ private:
 
 	int mWordCount, mCitCount;
 
+    QString m_filter; // for showing also cwls which contain the filter string (by default hidden)
+
 	QList<CompletionWord>::iterator it;
 
 	static LatexCompleterConfig *config;
