@@ -146,7 +146,7 @@ void LatexStyleParser::run()
         QStringList included = results.filter(QRegularExpression("#include:.+"));
 		foreach (QString elem, included) {
 			elem = elem.mid(9);
-			if (!QFileInfo("cwl:" + elem + ".cwl").exists()) {
+            if (!QFileInfo::exists("cwl:" + elem + ".cwl")) {
 				QString hlp = kpsewhich(elem + ".sty");
 				if (!hlp.isEmpty()) {
                     if (!topPackage.isEmpty()){
@@ -424,6 +424,7 @@ bool LatexStyleParser::parseLineNewLength(QStringList &results, const QString &l
 	if (name.contains("@")) {
 		return true;
 	}
+    name.append("#*L");
 	if (!results.contains(name)) {
 		results << name;
 	}
@@ -442,6 +443,7 @@ bool LatexStyleParser::parseLineNewCounter(QStringList &results, const QString &
 	if (name.contains("@")) {
 		return true;
 	}
+	name.append("#S");
 	if (!results.contains(name)) {
 		results << name;
 	}
@@ -819,8 +821,7 @@ QStringList LatexStyleParser::readPackageTracing(QString fn) const
 
 	QString tempPath = QDir::tempPath() + QDir::separator() + "." + QDir::separator();
 	QTemporaryFile *tf = new QTemporaryFile(tempPath + "XXXXXX.tex");
-	if (!tf) return QStringList();
-	tf->open();
+    if (!tf || !tf->open()) return QStringList();
 
 	QTextStream out(tf);
 	out << "\\documentclass{article}\n";
