@@ -55,6 +55,7 @@ PDFDock::~PDFDock()
 
 void PDFDock::documentLoaded()
 {
+	filled = false;
 	if (!isHidden()) {
 		fillInfo();
 		filled = true;
@@ -412,6 +413,7 @@ void PDFFontsDock::fillInfo()
 {
 	if (!document) return;
 	QSharedPointer<Poppler::Document> spDoc(document->popplerDoc());
+	if (!spDoc) return;
 	if (!scannedFonts) {
 		fonts = spDoc->fonts();
 		scannedFonts = true;
@@ -734,8 +736,8 @@ void PDFScrollArea::setContinuous(bool cont)
 {
 	Q_ASSERT(pdf);
 	if (cont == continuous) return;
-	continuous = cont;
-	if (!cont) pdf->setGridSize(pdf->gridCols(), 1);
+    continuous = cont;
+    if (!cont) pdf->setGridSize(pdf->gridCols(true), pdf->gridRows(true));
 	else {
 		int page = pdf->getPageIndex();
         resizeEvent(nullptr);
@@ -747,7 +749,7 @@ void PDFScrollArea::goToPage(int page, bool sync)
 {
 	if (continuous) {
 		int rowHeight = pdf->gridRowHeight();
-		verticalScrollBar()->setValue((page / pdf->gridCols())  * rowHeight);
+        verticalScrollBar()->setValue(((page+pdf->getPageOffset())/ pdf->gridCols())  * rowHeight);
 	} else pdf->goToPageDirect(page, sync);
 }
 
