@@ -114,6 +114,7 @@ void SyntaxCheck::run()
                 mReplacementList=newReplacementList;
                 mFormatList=newFormatList;
                 m_nonTextGrammarFormats=m_newNonTextGrammarFormats;
+                m_RainbowFormats=m_newRainbowFormats;
 			}
 			mLtxCommandLock.unlock();
 		}
@@ -146,6 +147,7 @@ void SyntaxCheck::run()
         if (newLine.clearOverlay){
             QList<int> fmtList={syntaxErrorFormat,SpellerUtility::spellcheckErrorFormat};
             fmtList.append(mFormatList.values());
+            fmtList.append(m_RainbowFormats);
             newLine.dlh->clearOverlays(fmtList);
         }
 		//if(newRanges.isEmpty()) continue;
@@ -334,6 +336,27 @@ void SyntaxCheck::setNonTextGrammarFormats(const QList<int> formats)
     m_newNonTextGrammarFormats=formats;
     mLtxCommandLock.unlock();
 }
+/*!
+ * \brief enable/disable rainbow delimiters
+ * \param enable
+ */
+void SyntaxCheck::enableRainbowDelimiter(bool enable)
+{
+    mShowRainbowDelimiter=enable;
+}
+/*!
+ * \brief set colors for rainbow delimiters
+ * \param formats
+ */
+void SyntaxCheck::setDelimiterFormats(const QList<int> formats)
+{
+
+    if (stopped) return;
+    mLtxCommandLock.lock();
+    newLtxCommandsAvailable = true;
+    m_newRainbowFormats=formats;
+    mLtxCommandLock.unlock();
+}
 /*!
  * \brief set character/text replacementList for spell checking
  * \param replacementList Map for characater/text replacement prior to spellchecking words. E.g. "u -> ü when german is activated
@@ -540,6 +563,8 @@ bool SyntaxCheck::equalEnvStack(StackEnvironment env1, StackEnvironment env2)
 */
 void SyntaxCheck::markUnclosedEnv(Environment env)
 {
+    if(!mSyntaxChecking) return; // skip when no syntax errors are to be shown
+
 	QDocumentLineHandle *dlh = env.dlh;
 	if (!dlh)
 		return;
@@ -730,6 +755,36 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 				newRanges.append(elem);
 			}
 		}
+        // rainbow delimiter
+        if(mShowRainbowDelimiter && tk.type==Token::braces){
+            Error elem;
+            elem.range = QPair<int, int>(tk.start, 1);
+            elem.type = ERR_highlight;
+            int lvl=tk.level % 8;
+            if(lvl<0) lvl=0;
+            elem.format=m_RainbowFormats[lvl];
+            newRanges.append(elem);
+            elem.range = QPair<int, int>(tk.start+tk.length-1, 1);
+            newRanges.append(elem);
+        }
+        if(mShowRainbowDelimiter && tk.type==Token::openBrace){
+            Error elem;
+            elem.range = QPair<int, int>(tk.start, 1);
+            elem.type = ERR_highlight;
+            int lvl=tk.level % 8;
+            if(lvl<0) lvl=0;
+            elem.format=m_RainbowFormats[lvl];
+            newRanges.append(elem);
+        }
+        if(mShowRainbowDelimiter && tk.type==Token::closeBrace){
+            Error elem;
+            elem.range = QPair<int, int>(tk.start, 1);
+            elem.type = ERR_highlight;
+            int lvl=tk.level % 8;
+            if(lvl<0) lvl=0;
+            elem.format=m_RainbowFormats[lvl];
+            newRanges.append(elem);
+        }
         // math highlighting of formula
         if(tk.subtype==Token::formula){
             // highlight
@@ -989,6 +1044,12 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                                         if(newRanges.last().range==QPair<int,int>(tk.start,tk.length)){
                                             // yes, remove !
                                             newRanges.removeLast();
+                                        }else{
+                                            // check the one before as well (as rainbow braces may have been added)
+                                            if(mShowRainbowDelimiter && newRanges.size()>2 && newRanges.value(newRanges.size()-3).range==QPair<int,int>(tk.start,tk.length)){
+                                                // yes, remove !
+                                                newRanges.removeAt(newRanges.size()-3);
+                                            }
                                         }
                                     }
                                 }
@@ -1045,6 +1106,10 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 						option="ll"; // is always 2 columns
 					}else{
                         option = Parsing::getArg(tl.mid(i+1),Token::colDef);
+                        if(option.isEmpty()){
+                            // check if multiline arg
+                            option = Parsing::getArg(tl.mid(i+1),dlh,0,ArgumentList::Mandatory);
+                        }
 					}
 				}
                 if(option.contains("colspec")){
@@ -1179,7 +1244,22 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                     }
 					continue;
 				}
-
+                // special treatment { \\ } in tblr (multirow cell)
+                if(word=="\\\\" && activeEnv.top().name=="tblr"){
+                    // check if this token lies with braces/none
+                    bool skipToken=false;
+                    for(int j=i-1;j>=0;--j){
+                        Token tk2=tl.at(j);
+                        if(tk2.type==Token::braces && tk2.subtype==Token::none && tk2.start+tk2.length>tk.start){
+                            // inside braces, ignore
+                            skipToken=true;
+                            break;
+                        }
+                    }
+                    if(skipToken){
+                        continue;
+                    }
+                }
 				if ((word == "\\\\") || (word == "\\tabularnewline")) {
 					if (activeEnv.top().excessCol < (activeEnv.top().id - 1)) {
 						Error elem;
@@ -1244,6 +1324,18 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
             if (ltxCommands->possibleCommands["user"].contains(word))
 				continue;
 
+            if(tk.subtype >= Token::specialArg){
+                // from multi element special argument
+                QString value = line.mid(tk.start, tk.length);
+                QString special = ltxCommands->mapSpecialArgs.value(int(tk.subtype - Token::specialArg));
+                if (!ltxCommands->possibleCommands[special].contains(value)) {
+                    Error elem;
+                    elem.range = QPair<int, int>(tk.start, tk.length);
+                    elem.type = ERR_unrecognizedKey;
+                    newRanges.append(elem);
+                }
+                continue;
+            }
 			if (!checkCommand(word, activeEnv)) {
 				Error elem;
 				if (tkEnvName.type == Token::braces) {
@@ -1283,7 +1375,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                 }
 			}
 		}
-		if (tk.type == Token::specialArg) {
+        if (tk.type >= Token::specialArg) {
 			QString value = line.mid(tk.start, tk.length);
 			QString special = ltxCommands->mapSpecialArgs.value(int(tk.type - Token::specialArg));
 			if (!ltxCommands->possibleCommands[special].contains(value)) {
@@ -1420,9 +1512,12 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 					if(options.startsWith("#")){
 						continue; // ignore type keys, like width#L
 					}
+                    if(options.endsWith("#c")){
+                        continue; // ignore values for syntax checking (#c)
+                    }
                     if(options.startsWith("%")){
                         if (!ltxCommands->possibleCommands[options].contains(word)) {
-                            // special treatement for %color (mix)
+                            // special treatment for %color (mix)
                             if(options=="%color"){
                                 if(word=="!") continue;
                                 bool ok;
@@ -1435,10 +1530,27 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                             newRanges.append(elem);
                         }
                     }else{
+                        if(options.contains(" ")){
+                            // special treatment for values with spaces, i.e. multi word values
+                            for (int k = i + 1; k < tl.length(); ++k) {
+                                Token tk_elem = tl.at(k);
+                                if(tk_elem.subtype!=Token::keyVal_val){
+                                    tk_elem=tl.at(k-1);
+                                    word=line.mid(tk.start,tk_elem.start+tk_elem.length-tk.start); // combine multiple keyVal_val tokens if present
+                                    i=k-1; // skip over those tokens
+                                    break;
+                                }
+                                if(k==tl.length()-1){
+                                    // last token
+                                    word=line.mid(tk.start,tk_elem.start+tk_elem.length-tk.start); // combine multiple keyVal_val tokens if present
+                                    i=k; // skip over those tokens
+                                }
+                            }
+                        }
                         QStringList l = options.split(",");
                         if (!l.contains(word)) {
                             Error elem;
-                            elem.range = QPair<int, int>(tk.start, tk.length);
+                            elem.range = QPair<int, int>(tk.start, word.length());
                             elem.type = ERR_unrecognizedKeyValues;
                             newRanges.append(elem);
                         }
@@ -1451,6 +1563,14 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
         // merge original parenthesis vector with new additions
         // skip duplicates
         QVector<QParenthesis> original_parens=dlh->parenthesis();
+        // remove id 61 as it was added by syntaxcheck earlier
+        for(int i=0;i<original_parens.size();++i){
+            if(original_parens[i].id==61){
+                // remove
+                original_parens.remove(i);
+                --i;
+            }
+        }
         QVector<QParenthesis> result;
         int i=0;
         for(int j=0;j<m_parens.length();++j){
